summaryrefslogtreecommitdiffstats
path: root/languages/cpp/cppsupportpart.h
diff options
context:
space:
mode:
authortpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
committertpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>2011-06-14 16:45:05 +0000
commit48d4a26399959121f33d2bc3bfe51c7827b654fc (patch)
tree5ae5e6e00d3ba330b7b8be9bc097154b6bc739e8 /languages/cpp/cppsupportpart.h
parent7e701ace6592d09e1f2c0cf28c7d6d872d78f4f5 (diff)
downloadtdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.tar.gz
tdevelop-48d4a26399959121f33d2bc3bfe51c7827b654fc.zip
TQt4 port kdevelop
This enables compilation under both Qt3 and Qt4 git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdevelop@1236710 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
Diffstat (limited to 'languages/cpp/cppsupportpart.h')
-rw-r--r--languages/cpp/cppsupportpart.h30
1 files changed, 16 insertions, 14 deletions
diff --git a/languages/cpp/cppsupportpart.h b/languages/cpp/cppsupportpart.h
index 00628c94..b9d5a53f 100644
--- a/languages/cpp/cppsupportpart.h
+++ b/languages/cpp/cppsupportpart.h
@@ -39,9 +39,10 @@
///A class that helps detecting what exactly makes the UI block. To use it, just place a breakpoint on UIBlockTester::lockup() and inspect the execution-position of the main thread
class UIBlockTester : public TQObject {
Q_OBJECT
+ TQ_OBJECT
class UIBlockTesterThread : public TQThread {
public:
- UIBlockTesterThread( UIBlockTester& parent );
+ UIBlockTesterThread( UIBlockTester& tqparent );
void run();
void stop();
private:
@@ -74,7 +75,7 @@ class CppCodeCompletion;
class CppCodeCompletionConfig;
class CppSplitHeaderSourceConfig;
class CreateGetterSetterConfiguration;
-class QtBuildConfig;
+class TQtBuildConfig;
class ProblemReporter;
class BackgroundParser;
class Catalog;
@@ -142,7 +143,7 @@ public:
m_fileSet.insert( s );
}
- bool contains( const HashedString& str ) const {
+ bool tqcontains( const HashedString& str ) const {
TQMutexLocker locker( &m_mutex );
return m_fileSet.find( str ) != m_fileSet.end();
}
@@ -155,9 +156,10 @@ private:
class CppSupportPart : public KDevLanguageSupport
{
Q_OBJECT
+ TQ_OBJECT
public:
- CppSupportPart( TQObject *parent, const char *name, const TQStringList &args );
+ CppSupportPart( TQObject *tqparent, const char *name, const TQStringList &args );
virtual ~CppSupportPart();
bool isValid() const
@@ -203,10 +205,10 @@ public:
}
/**
- Get a pointer to the QtBuildConfig object
- @return A pointer to the QtBuildConfig object.
+ Get a pointer to the TQtBuildConfig object
+ @return A pointer to the TQtBuildConfig object.
*/
- inline QtBuildConfig* qtBuildConfig() const { return m_qtBuildConfig; }
+ inline TQtBuildConfig* qtBuildConfig() const { return m_qtBuildConfig; }
const TQPtrList<Catalog>& catalogList() const
{
@@ -415,7 +417,7 @@ private:
KAction * m_createGetterSetterAction;
KAction * m_switchHeaderSourceAction;
- QtBuildConfig* m_qtBuildConfig;
+ TQtBuildConfig* m_qtBuildConfig;
bool withcpp;
TQString m_contextFileName;
@@ -481,7 +483,7 @@ private:
{
}
};
//typedef QPair<TQStringList, TQStringList> Item; ///The files we are waiting fore, and the files we already got
typedef TQValueList< Item > List;
List m_waiting;
@@ -510,7 +512,7 @@ private:
///files that were not requested must not be processed, since they maybe do not respect the group-relationships.
bool reject( TQString file ) {
for( List::iterator it = m_waiting.begin(); it != m_waiting.end(); ++it) {
- if( (*it).first.find( file ) != (*it).first.end() ) {
+ if( (*it).first.tqfind( file ) != (*it).first.end() ) {
return false;
}
}
@@ -520,7 +522,7 @@ private:
bool waiting( TQString file, Flags forbidFlags = None, int count = 1 ) const {
int hits = 0;
for( List::const_iterator it = m_waiting.begin(); it != m_waiting.end(); ++it) {
- if( (*it).first.find( file ) != (*it).first.end() ) {
+ if( (*it).first.tqfind( file ) != (*it).first.end() ) {
if( ((Flags)((*it).flags & forbidFlags )) == None ) {
hits++;
if( hits >= count ) return true;
@@ -575,8 +577,8 @@ private:
Processed processFile( TQString file, Flags flag = None ) {
TQStringList ret;
for( List::iterator it = m_waiting.begin(); it != m_waiting.end(); ++it) {
- if( (*it).first.find( file ) != (*it).first.end() ) {
- if( (*it).second.find( file ) == (*it).second.end() ) {
+ if( (*it).first.tqfind( file ) != (*it).first.end() ) {
+ if( (*it).second.tqfind( file ) == (*it).second.end() ) {
(*it).flags = (Flags) ((*it).flags | flag);
(*it).second << file;
if( (*it).second.count() == (*it).first.count() ) {
@@ -642,7 +644,7 @@ private:
int lastBackgroundState;
int backgroundState;
TQStringList reparseList;
- TQMap< TQString, QPair<uint, uint> > pcs;
+ TQMap< TQString, TQPair<uint, uint> > pcs;
TQDataStream stream;
TQFile file;
TQTime lastParse;
@@ -481,7 +483,7 @@ private:
}
};
- //typedef QPair<TQStringList, TQStringList> Item; ///The files we are waiting fore, and the files we already got
+ //typedef TQPair<TQStringList, TQStringList> Item; ///The files we are waiting fore, and the files we already got
typedef TQValueList< Item > List;
List m_waiting;